##  Use Cases
SAP LeanIX REST APIs provide access to various resources. You can use them to import and export data, set up integrations, and automate workflows for your organization.
Here are some example use cases:
  * [Update user permissions through the MTM API](https://help.sap.com/docs/leanix/ea/updating-user-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Update user permissions through the MTM REST API.")
  * [Get survey results using the Poll API](https://help.sap.com/docs/leanix/ea/retrieving-survey-results?locale=en-US&state=PRODUCTION&version=CLOUD "Retrieve survey results using the Survey REST API.")


YesNo
Send
